import { render, screen } from '@testing-library/react'
import { FluidType } from 'enums'
import { MonthlyForecast } from 'models'
import React from 'react'
import { mockMonthlyForecastJanuaryTestProfile1 } from 'tests/__mocks__/profileType.mock'
import ProfileComparatorRow from './ProfileComparatorRow'

describe('AnalysisConsumptionRow component', () => {
  const userPriceConsumption = 20
  const homePriceConsumption = 18
  const performanceValue = 25

  describe('Multifluid row', () => {
    it('should be rendered correctly for Multifluid and at least fluid connected', async () => {
      const { container } = render(
        <ProfileComparatorRow
          fluid={FluidType.MULTIFLUID}
          userPriceConsumption={20}
          homePriceConsumption={18}
          performanceValue={null}
          forecast={mockMonthlyForecastJanuaryTestProfile1}
          connected={true}
          noData={false}
        />
      )
      expect(
        container.getElementsByClassName('consumption-multifluid').length
      ).toBeTruthy()
      expect(screen.getByTestId('userPrice')).toHaveTextContent('20,00 €')
      expect(screen.getByTestId('averagePrice')).toHaveTextContent('18,00 €')
      expect(container.getElementsByClassName('graph').length).toBeTruthy()
      expect(
        container.getElementsByClassName('not-connected').length
      ).toBeFalsy()
    })

    it('should be rendered correctly for Multifluid and at none fluid connected', async () => {
      const mockConnected = false
      const { container } = render(
        <ProfileComparatorRow
          fluid={FluidType.MULTIFLUID}
          userPriceConsumption={userPriceConsumption}
          homePriceConsumption={homePriceConsumption}
          performanceValue={null}
          forecast={mockMonthlyForecastJanuaryTestProfile1}
          connected={mockConnected}
          noData={false}
        />
      )
      expect(
        container.getElementsByClassName('consumption-multifluid').length
      ).toBeTruthy()
      expect(screen.getByTestId('userPrice')).toHaveTextContent(
        'analysis.no_data'
      )
      expect(screen.getByTestId('averagePrice')).toHaveTextContent('18,00 €')
      expect(container.getElementsByClassName('graph').length).toBeFalsy()
      expect(
        container.getElementsByClassName('not-connected').length
      ).toBeTruthy()
    })
  })

  describe('Single fluid row', () => {
    it('should be rendered correctly for singleFluid connected for average', async () => {
      const { container } = render(
        <ProfileComparatorRow
          fluid={FluidType.ELECTRICITY}
          userPriceConsumption={userPriceConsumption}
          homePriceConsumption={homePriceConsumption}
          performanceValue={performanceValue}
          forecast={mockMonthlyForecastJanuaryTestProfile1}
          connected={true}
          noData={false}
        />
      )

      expect(
        container.getElementsByClassName('consumption-electricity').length
      ).toBeTruthy()
      expect(screen.getByTestId('userPrice')).toHaveTextContent(
        '25 FLUID.ELECTRICITY.UNIT'
      )
      expect(screen.getByTestId('averagePrice')).toHaveTextContent(
        '4340 FLUID.ELECTRICITY.UNIT'
      )
      expect(container.getElementsByClassName('graph').length).toBeTruthy()
      expect(
        container.getElementsByClassName('not-connected').length
      ).toBeFalsy()
    })

    it('should be rendered correctly for singleFluid not connected', async () => {
      const mockConnected = false
      const { container } = render(
        <ProfileComparatorRow
          fluid={FluidType.ELECTRICITY}
          userPriceConsumption={userPriceConsumption}
          homePriceConsumption={homePriceConsumption}
          performanceValue={performanceValue}
          forecast={mockMonthlyForecastJanuaryTestProfile1}
          connected={mockConnected}
          noData={false}
        />
      )

      expect(
        container.getElementsByClassName('consumption-electricity').length
      ).toBeTruthy()
      expect(screen.getByTestId('userPrice')).toHaveTextContent(
        'analysis.no_data'
      )
      expect(screen.getByTestId('averagePrice')).toHaveTextContent(
        '4340 FLUID.ELECTRICITY.UNIT'
      )
      expect(container.getElementsByClassName('graph').length).toBeFalsy()
      expect(
        container.getElementsByClassName('not-connected').length
      ).toBeTruthy()
    })

    it('should be rendered correctly for singleFluid with none performance value', async () => {
      const mockPerformanceValue: number | null = null
      const { container } = render(
        <ProfileComparatorRow
          fluid={FluidType.ELECTRICITY}
          userPriceConsumption={userPriceConsumption}
          homePriceConsumption={homePriceConsumption}
          performanceValue={mockPerformanceValue}
          forecast={mockMonthlyForecastJanuaryTestProfile1}
          connected={true}
          noData={false}
        />
      )

      expect(
        container.getElementsByClassName('consumption-electricity').length
      ).toBeTruthy()
      expect(screen.getByTestId('userPrice')).toHaveTextContent('-')
      expect(screen.getByTestId('averagePrice')).toHaveTextContent(
        '4340 FLUID.ELECTRICITY.UNIT'
      )
      expect(container.getElementsByClassName('graph').length).toBeTruthy()
      expect(
        container.getElementsByClassName('not-connected').length
      ).toBeFalsy()
    })

    it('should be rendered correctly with unit', async () => {
      const mockForecast: MonthlyForecast = {
        ...mockMonthlyForecastJanuaryTestProfile1,
        fluidForecast: [
          {
            detailsMonthlyForecast:
              mockMonthlyForecastJanuaryTestProfile1.fluidForecast[0]
                .detailsMonthlyForecast,
            fluidType: 0,
            load: 50,
            value: 25,
          },
        ],
      }
      const { container } = render(
        <ProfileComparatorRow
          fluid={FluidType.ELECTRICITY}
          userPriceConsumption={userPriceConsumption}
          homePriceConsumption={homePriceConsumption}
          performanceValue={performanceValue}
          forecast={mockForecast}
          connected={true}
          noData={false}
        />
      )
      expect(
        container.getElementsByClassName('consumption-electricity').length
      ).toBeTruthy()
      expect(screen.getByTestId('userPrice')).toHaveTextContent(
        '25 FLUID.ELECTRICITY.UNIT'
      )
      expect(screen.getByTestId('averagePrice')).toHaveTextContent(
        '50 FLUID.ELECTRICITY.UNIT'
      )
      expect(container.getElementsByClassName('graph').length).toBeTruthy()
      expect(
        container.getElementsByClassName('not-connected').length
      ).toBeFalsy()
    })
  })
})
