import { render, screen } from '@testing-library/react'
import { userEvent } from '@testing-library/user-event'
import React from 'react'
import { Provider } from 'react-redux'
import { SgeStatusWithAccount } from 'tests/__mocks__/fluidStatusData.mock'
import { createMockEcolyoStore, mockGlobalState } from 'tests/__mocks__/store'
import SgeInit from './SgeInit'

const mockedNavigate = jest.fn()
jest.mock('react-router-dom', () => ({
  ...jest.requireActual('react-router-dom'),
  useNavigate: () => mockedNavigate,
}))

const mockConnect = jest.fn()
const mockUpdate = jest.fn()

jest.mock('components/Hooks/useKonnectorAuth', () =>
  jest.fn(() => [mockConnect, mockUpdate])
)

describe('SgeInit component', () => {
  const store = createMockEcolyoStore()
  it('should be rendered correctly', () => {
    const { container } = render(
      <Provider store={store}>
        <SgeInit />
      </Provider>
    )
    expect(container).toMatchSnapshot()
  })
  it('should go to sge connect steps', async () => {
    render(
      <Provider store={store}>
        <SgeInit />
      </Provider>
    )
    await userEvent.click(screen.getAllByRole('button')[0])
    expect(mockedNavigate).toHaveBeenCalled()
  })
  it('should launch account and trigger creation process', async () => {
    const store = createMockEcolyoStore({
      global: {
        ...mockGlobalState,
        sgeConnect: {
          ...mockGlobalState.sgeConnect,
          shouldLaunchAccount: true,
        },
      },
    })

    render(
      <Provider store={store}>
        <SgeInit />
      </Provider>
    )
    expect(mockConnect).toHaveBeenCalled()
  })
  it('should launch existing account update process', async () => {
    const store = createMockEcolyoStore({
      global: {
        ...mockGlobalState,
        fluidStatus: [SgeStatusWithAccount],
        sgeConnect: {
          ...mockGlobalState.sgeConnect,
          shouldLaunchAccount: true,
        },
      },
    })
    render(
      <Provider store={store}>
        <SgeInit />
      </Provider>
    )
    expect(mockUpdate).toHaveBeenCalled()
  })
})
