import { render, screen } from '@testing-library/react'
import { userEvent } from '@testing-library/user-event'
import { DataloadState, FluidType } from 'enums'
import React from 'react'
import { baseDataLoad } from 'tests/__mocks__/chartData.mock'
import DataloadNoValue from './DataloadNoValue'

describe('DataloadNoValue component', () => {
  it('should render correctly', () => {
    const { container } = render(
      <DataloadNoValue
        dataload={baseDataLoad}
        fluidType={FluidType.ELECTRICITY}
        setActive={jest.fn()}
      />
    )
    expect(container).toMatchSnapshot()
  })

  describe('should render correctly no data', () => {
    it('case state EMPTY', () => {
      const mockDataLoad = { ...baseDataLoad, state: DataloadState.EMPTY }
      render(
        <DataloadNoValue
          dataload={mockDataLoad}
          fluidType={FluidType.ELECTRICITY}
          setActive={jest.fn()}
        />
      )
      expect(
        screen.getByText('consumption_visualizer.no_data')
      ).toBeInTheDocument()
    })
    it('case state HOLE', () => {
      const mockDataLoad = { ...baseDataLoad, state: DataloadState.HOLE }
      render(
        <DataloadNoValue
          dataload={mockDataLoad}
          fluidType={FluidType.ELECTRICITY}
          setActive={jest.fn()}
        />
      )
      expect(
        screen.getByText('consumption_visualizer.no_data')
      ).toBeInTheDocument()
    })
    it('case state AGGREGATED_EMPTY', () => {
      const mockDataLoad = {
        ...baseDataLoad,
        state: DataloadState.AGGREGATED_EMPTY,
      }
      render(
        <DataloadNoValue
          dataload={mockDataLoad}
          fluidType={FluidType.MULTIFLUID}
          setActive={jest.fn()}
        />
      )
      expect(
        screen.getByText('consumption_visualizer.no_data')
      ).toBeInTheDocument()
    })
  })

  describe('should render correctly missing data', () => {
    it('case state MISSING', () => {
      const mockDataLoad = { ...baseDataLoad, state: DataloadState.MISSING }
      render(
        <DataloadNoValue
          dataload={mockDataLoad}
          fluidType={FluidType.ELECTRICITY}
          setActive={jest.fn()}
        />
      )
      expect(
        screen.getByText('consumption_visualizer.missing_data')
      ).toBeInTheDocument()
    })
    it('case state AGGREGATED_HOLE_OR_MISSING', () => {
      const mockDataLoad = {
        ...baseDataLoad,
        state: DataloadState.AGGREGATED_HOLE_OR_MISSING,
      }
      render(
        <DataloadNoValue
          dataload={mockDataLoad}
          fluidType={FluidType.MULTIFLUID}
          setActive={jest.fn()}
        />
      )
      expect(
        screen.getByText('consumption_visualizer.missing_data')
      ).toBeInTheDocument()
    })
  })

  it('should call setActive when missing message is clicked', async () => {
    const mockSetActive = jest.fn()
    const mockDataLoad = { ...baseDataLoad, state: DataloadState.MISSING }
    render(
      <DataloadNoValue
        dataload={mockDataLoad}
        fluidType={FluidType.ELECTRICITY}
        setActive={mockSetActive}
      />
    )
    await userEvent.click(screen.getByRole('button'))
    expect(mockSetActive).toHaveBeenCalledWith(true)
  })
})
