import Button from '@material-ui/core/Button'
import Dialog from '@material-ui/core/Dialog'
import challengeWon from 'assets/icons/visu/duelResult/challengeWon.svg'
import defaultIcon from 'assets/icons/visu/duelResult/default.svg'
import { useI18n } from 'cozy-ui/transpiled/react/I18n'
import Icon from 'cozy-ui/transpiled/react/Icon'
import { UserChallenge } from 'models'
import React, { useEffect, useState } from 'react'
import { formatNumberValues, importIconById } from 'utils/utils'
import './duelResultModal.scss'

interface DuelResultModalProps {
  open: boolean
  userChallenge: UserChallenge
  win: boolean
  handleCloseClick: () => void
}

const DuelResultModal = ({
  open,
  userChallenge,
  win,
  handleCloseClick,
}: DuelResultModalProps) => {
  const { t } = useI18n()
  const [winIcon, setWinIcon] = useState<string>(defaultIcon)
  const [lossIcon, setLossIcon] = useState<string>(defaultIcon)
  const result = formatNumberValues(
    Math.abs(userChallenge.duel.threshold - userChallenge.duel.userConsumption)
  )

  const statusKey = win ? 'success' : 'lost'

  useEffect(() => {
    async function handleEcogestureIcon() {
      const icon = await importIconById(userChallenge.id + '-1', 'duelResult')
      setWinIcon(icon || defaultIcon)
      const icon2 = await importIconById(userChallenge.id + '-0', 'duelResult')
      setLossIcon(icon2 || defaultIcon)
    }
    handleEcogestureIcon()
  }, [userChallenge])

  return (
    <Dialog
      open={open}
      onClose={handleCloseClick}
      aria-labelledby="accessibility-title"
      classes={{
        root: 'modal-root',
        paper: 'modal-paper blue-border',
      }}
    >
      <div id="accessibility-title">
        {t('duel_result_modal.accessibility.window_title')}
      </div>
      <div className="duel-result-modal-root">
        <div className="imgResultContainer">
          {win && (
            <Icon className="challengeWon" icon={challengeWon} size={300} />
          )}
          <Icon
            className="imgResult"
            icon={win ? winIcon : lossIcon}
            size={180}
          />
        </div>
        <div className="text-28-normal-uppercase title">
          {t(`duel_result_modal.${statusKey}.title`)}
        </div>
        <div className="text-18-bold">
          {t(`duel_result_modal.${statusKey}.message1`, { value: result })}
        </div>
        <div className="text-18-bold">
          {t(`duel_result_modal.${statusKey}.message2`, {
            title: userChallenge.title,
          })}
        </div>
        <Button
          aria-label={t('duel_result_modal.accessibility.button_validate')}
          className="btnSecondary"
          onClick={handleCloseClick}
        >
          {t(`duel_result_modal.${statusKey}.button_validate`)}
        </Button>
      </div>
    </Dialog>
  )
}

export default DuelResultModal
