import { render, screen, waitFor } from '@testing-library/react'
import { userEvent } from '@testing-library/user-event'
import React from 'react'
import { Provider } from 'react-redux'
import { BrowserRouter } from 'react-router-dom'
import * as storeHooks from 'store/hooks'
import { mockedEcogesturesData } from 'tests/__mocks__/ecogesturesData.mock'
import { createMockEcolyoStore } from 'tests/__mocks__/store'
import EcogestureList from './EcogestureList'

const mockedNavigate = jest.fn()
jest.mock('react-router-dom', () => ({
  ...jest.requireActual('react-router-dom'),
  useNavigate: () => mockedNavigate,
}))

jest.mock(
  'components/Ecogesture/EcogestureCard/EcogestureCard',
  () => 'mock-ecogesturecard'
)

const mockHandleReinit = jest.fn()
const updateEcogestureFilter = jest.fn()
const mockAppDispatch = jest.spyOn(storeHooks, 'useAppDispatch')
mockAppDispatch.mockImplementation(() => updateEcogestureFilter)

const store = createMockEcolyoStore()

describe('EcogesturesList component', () => {
  beforeAll(() => {
    mockAppDispatch.mockClear()
  })
  it('should be rendered correctly', async () => {
    const { container } = render(
      <Provider store={store}>
        <BrowserRouter>
          <EcogestureList
            list={mockedEcogesturesData}
            displaySelection={false}
            selectionTotal={0}
            selectionViewed={0}
            handleReinitClick={mockHandleReinit}
          />
        </BrowserRouter>
      </Provider>
    )
    expect(container).toMatchSnapshot()
  })

  it('should open the filter menu and select all ecogesture', async () => {
    const { container } = render(
      <Provider store={store}>
        <BrowserRouter>
          <EcogestureList
            list={mockedEcogesturesData}
            displaySelection={false}
            selectionTotal={0}
            selectionViewed={0}
          />
        </BrowserRouter>
      </Provider>
    )
    await waitFor(() => null, { container })
    await userEvent.click(screen.getAllByRole('button')[0])
    await userEvent.click(screen.getAllByRole('menuitem')[1])
    expect(updateEcogestureFilter).toHaveBeenCalledTimes(1)
  })

  it('should go to "/ecogesture-selection"', async () => {
    const { container } = render(
      <Provider store={store}>
        <BrowserRouter>
          <EcogestureList
            list={mockedEcogesturesData}
            displaySelection={true}
            selectionTotal={50}
            selectionViewed={10}
          />
        </BrowserRouter>
      </Provider>
    )
    await waitFor(() => null, { container })
    await userEvent.click(screen.getAllByRole('button')[1])
    expect(mockedNavigate).toHaveBeenCalledWith('/ecogesture-selection')
  })
})
