import { render, screen, waitFor } from '@testing-library/react'
import { userEvent } from '@testing-library/user-event'
import React from 'react'
import { mockedEcogesturesData } from 'tests/__mocks__/ecogesturesData.mock'
import EcogestureSelectionDetail from './EcogestureSelectionDetail'

const mockValidate = jest.fn()

describe('EcogestureSelectionDetail component', () => {
  it('should be rendered correctly', async () => {
    const { container } = render(
      <EcogestureSelectionDetail
        ecogesture={mockedEcogesturesData[0]}
        validate={mockValidate}
        title={mockedEcogesturesData[0].shortName}
      />
    )
    await waitFor(() => null, { container })
    expect(container).toMatchSnapshot()
  })

  describe('should click on buttons', () => {
    let container: HTMLElement
    beforeEach(async () => {
      container = render(
        <EcogestureSelectionDetail
          ecogesture={mockedEcogesturesData[0]}
          validate={mockValidate}
          title={mockedEcogesturesData[0].shortName}
        />
      ).container
      await waitFor(() => null, { container })
    })

    it('should toggle more details', async () => {
      const [showMore] = screen.getAllByRole('button')
      await userEvent.click(showMore)
      expect(screen.getByText('ecogesture_modal.show_less')).toBeInTheDocument()
    })
    it('should call validate with objective to true', async () => {
      const [, objective] = screen.getAllByRole('button')
      await userEvent.click(objective)
      expect(mockValidate).toHaveBeenCalledWith(true, false)
    })

    it('should call validate with doing to true', async () => {
      const [, , doing] = screen.getAllByRole('button')
      await userEvent.click(doing)
      expect(mockValidate).toHaveBeenCalledWith(false, true)
    })

    it('should call validate with objective and doing to false', async () => {
      const [, , , skip] = screen.getAllByRole('button')
      await userEvent.click(skip)
      expect(mockValidate).toHaveBeenCalledWith(false, false)
    })
  })
})
