import Button from '@material-ui/core/Button'
import starResult from 'assets/icons/visu/quiz/starResult.svg'
import StyledIcon from 'components/CommonKit/Icon/StyledIcon'
import { useClient } from 'cozy-client'
import { useI18n } from 'cozy-ui/transpiled/react/I18n'
import {
  UsageEventType,
  UserChallengeUpdateFlag,
  UserExplorationState,
} from 'enums'
import { UserChallenge } from 'models'
import React, { useCallback } from 'react'
import { useNavigate } from 'react-router-dom'
import ChallengeService from 'services/challenge.service'
import UsageEventService from 'services/usageEvent.service'
import { updateUserChallengeList } from 'store/challenge/challenge.slice'
import { toggleChallengeExplorationNotification } from 'store/global/global.slice'
import { useAppDispatch } from 'store/hooks'
import './explorationFinished.scss'

interface ExplorationFinishedProps {
  userChallenge: UserChallenge
}

const ExplorationFinished = ({ userChallenge }: ExplorationFinishedProps) => {
  const { t } = useI18n()
  const client = useClient()
  const dispatch = useAppDispatch()
  const navigate = useNavigate()

  const checkNotificationToEnd = useCallback(async () => {
    const challengeService = new ChallengeService(client)
    if (userChallenge.exploration.state === UserExplorationState.NOTIFICATION) {
      const updatedChallenge = await challengeService.updateUserChallenge(
        userChallenge,
        UserChallengeUpdateFlag.EXPLORATION_DONE
      )
      await UsageEventService.addEvent(client, {
        type: UsageEventType.EXPLORATION_END_EVENT,
        target: userChallenge.exploration.id,
        context: userChallenge.id,
        startDate: userChallenge.exploration.date,
      })
      dispatch(toggleChallengeExplorationNotification(false))
      dispatch(updateUserChallengeList(updatedChallenge))
    }
  }, [client, dispatch, userChallenge])

  const goBack = useCallback(async () => {
    await checkNotificationToEnd()
    navigate(-1)
  }, [navigate, checkNotificationToEnd])

  return (
    <div className="exploration-card">
      <div className="exploration-finish">
        <div className="congratulation">{t('exploration.congratulation')}</div>
        <div className="msg-success">
          {userChallenge.exploration.message_success}
        </div>
        <div className="exploration-earn">{t('exploration.earn')}</div>
        <div className="score-stars">
          5
          <StyledIcon
            className="exploration-icon"
            icon={starResult}
            size={30}
            role="img"
            title="Etoiles"
            ariaHidden={false}
          />
        </div>
        <Button
          aria-label={t('exploration.accessibility.button_confirm')}
          onClick={goBack}
          className="btnSecondary"
        >
          {t('exploration.button_confirm')}
        </Button>
      </div>
    </div>
  )
}

export default ExplorationFinished
