import { Button, IconButton } from '@material-ui/core'
import Dialog from '@material-ui/core/Dialog'
import CloseIcon from 'assets/icons/ico/close.svg'
import download from 'assets/icons/ico/download.svg'
import { useI18n } from 'cozy-ui/transpiled/react/I18n'
import Icon from 'cozy-ui/transpiled/react/Icon'
import React from 'react'
import './exportStartModal.scss'

interface ExportStartModalProps {
  open: boolean
  handleCloseClick: () => void
  handleDownloadClick: () => void
}

const ExportStartModal = ({
  open,
  handleCloseClick,
  handleDownloadClick,
}: ExportStartModalProps) => {
  const { t } = useI18n()

  return (
    <Dialog
      open={open}
      onClose={handleCloseClick}
      aria-labelledby="accessibility_title"
      classes={{
        root: 'modal-root',
        paper: 'modal-paper',
      }}
    >
      <div id="accessibility-title">
        {t('export.modal_start.accessibility_title')}
      </div>
      <div className="modal-start-root">
        <IconButton
          aria-label={t('export.button_close')}
          className="modal-paper-close-button"
          onClick={handleCloseClick}
        >
          <Icon icon={CloseIcon} size={18} />
        </IconButton>
        <div className="content">
          <div className="icon-main">
            <Icon icon={download} size={48} />
          </div>
          <div className="text-16-bold subtitle">
            {t('export.modal_start.text1')}
          </div>
          <div>
            {t('export.modal_start.text2')}
            <br />
            {t('export.modal_start.text3')}
          </div>
          <div className="buttons">
            <Button
              aria-label={t('export.modal_start.button_cancel')}
              onClick={handleCloseClick}
              className="btnSecondary"
            >
              {t('export.modal_start.button_cancel')}
            </Button>
            <Button
              aria-label={t('export.button_download')}
              onClick={handleDownloadClick}
              className="btnPrimary"
            >
              {t('export.button_download')}
            </Button>
          </div>
        </div>
      </div>
    </Dialog>
  )
}

export default ExportStartModal
