import { render, screen } from '@testing-library/react'
import userEvent from '@testing-library/user-event'
import React from 'react'
import { Provider } from 'react-redux'
import * as profileActions from 'store/profile/profile.slice'
import { createMockEcolyoStore } from 'tests/__mocks__/store'
import UnSubscribeView from './UnSubscribeView'

jest.mock('components/Header/CozyBar', () => 'mock-cozybar')
jest.mock('components/Header/Header', () => 'mock-header')
jest.mock('components/Content/Content', () => 'mock-content')

const mockUpdateProfile = jest.fn()
jest.mock('services/profile.service', () => {
  return jest.fn(() => ({
    updateProfile: mockUpdateProfile,
  }))
})
const updateProfileSpy = jest.spyOn(profileActions, 'updateProfile')
const mockedNavigate = jest.fn()
jest.mock('react-router-dom', () => ({
  ...jest.requireActual('react-router-dom'),
  useNavigate: () => mockedNavigate,
}))

describe('UnSubscribe component', () => {
  const store = createMockEcolyoStore()
  beforeEach(() => {
    jest.clearAllMocks()
  })

  it('should be rendered correctly', () => {
    const { container } = render(
      <Provider store={store}>
        <UnSubscribeView />
      </Provider>
    )
    expect(container).toMatchSnapshot()
  })

  it('should click on button and deactivate report', async () => {
    render(
      <Provider store={store}>
        <UnSubscribeView />
      </Provider>
    )
    await userEvent.click(screen.getByRole('button'))
    expect(updateProfileSpy).toHaveBeenCalledWith({
      sendAnalysisNotification: false,
    })
  })
})
