import Button from '@material-ui/core/Button'
import Dialog from '@material-ui/core/Dialog'
import { useI18n } from 'cozy-ui/transpiled/react/I18n'
import React from 'react'
import { useAppSelector } from 'store/hooks'
import './ReleaseNotesModal.scss'

interface ReleaseNotesModalProps {
  open: boolean
  handleCloseClick: () => void
}

const ReleaseNotesModal = ({
  open,
  handleCloseClick,
}: ReleaseNotesModalProps) => {
  const { t } = useI18n()
  const { releaseNotes } = useAppSelector(state => state.ecolyo.global)

  return (
    <Dialog
      open={open}
      disableEscapeKeyDown
      onClose={(event, reason): void => {
        event && reason !== 'backdropClick' && handleCloseClick()
      }}
      aria-labelledby="accessibility-title"
      classes={{
        root: 'modal-root',
        paper: 'modal-paper',
      }}
    >
      <div id="accessibility-title">
        {t(
          'consumption_visualizer.release_notes_modal.accessibility.window_title'
        )}
      </div>
      <div className="em-root release-note-container">
        <div className="em-content">
          <div className="release-note-title text-20-bold">
            {t('consumption_visualizer.release_notes_modal.title')}
          </div>
          <div className="release-note-message text-16-bold">
            {t('consumption_visualizer.release_notes_modal.message')}
          </div>
          <div className="release-note-message text-16-normal">
            {releaseNotes.notes.length > 0 &&
              releaseNotes.notes.map(note => (
                <div key={note.title} className="release-note-part">
                  <div className="release-note-message text-16-bold">
                    {note.title}
                  </div>
                  <div
                    className="release-note-description text-16-normal"
                    dangerouslySetInnerHTML={{ __html: note.description }}
                  />
                </div>
              ))}
          </div>
          <Button
            aria-label={t(
              'consumption_visualizer.release_notes_modal.accessibility.button_go_back'
            )}
            onClick={handleCloseClick}
            className="btnPrimary"
          >
            {t('consumption_visualizer.release_notes_modal.go_back')}
          </Button>
        </div>
      </div>
    </Dialog>
  )
}

export default ReleaseNotesModal
