import { render, screen } from '@testing-library/react'
import { userEvent } from '@testing-library/user-event'
import React from 'react'
import { Provider } from 'react-redux'
import * as storeHooks from 'store/hooks'
import { createMockEcolyoStore } from 'tests/__mocks__/store'
import { mockUpToDateTerm } from 'tests/__mocks__/termsData.mock'
import TermsView from './TermsView'

const mockCreateTerm = jest.fn()
jest.mock('services/terms.service', () => {
  return jest.fn(() => ({
    createTerm: mockCreateTerm,
    getTermsVersionType: jest.fn(),
  }))
})

const mockAppDispatch = jest.spyOn(storeHooks, 'useAppDispatch')

const mockUpdateProfile = jest.fn()
jest.mock('services/profile.service', () => {
  return jest.fn(() => ({
    updateProfile: mockUpdateProfile,
  }))
})

describe('TermsView component', () => {
  const store = createMockEcolyoStore()

  beforeEach(() => {
    jest.clearAllMocks()
  })

  it('should be rendered correctly', () => {
    const { container } = render(
      <Provider store={store}>
        <TermsView />
      </Provider>
    )
    expect(container).toMatchSnapshot()
  })
  it('should be unable to click "validate" button first then enable checkboxes and valid consent', async () => {
    mockCreateTerm.mockResolvedValueOnce(mockUpToDateTerm)
    render(
      <Provider store={store}>
        <TermsView />
      </Provider>
    )

    const acceptButton = screen.getAllByRole('button')[2]
    expect(acceptButton).toBeDisabled()
    expect(mockUpdateProfile).toHaveBeenCalledTimes(0)

    const [boxGCU, boxLegal] = screen.getAllByRole('checkbox')
    await userEvent.click(boxGCU)
    await userEvent.click(boxLegal)
    await userEvent.click(acceptButton)

    expect(mockAppDispatch).toHaveBeenCalledTimes(3)
  })
})
