import { FluidType } from 'enums'
import ConverterService from './converter.service'
import ConfigService from './fluidConfig.service'

describe('Converter service', () => {
  const converterService = new ConverterService()
  const configService = new ConfigService()
  describe('LoadToEuro method', () => {
    const fluidConfig = configService.getFluidConfig()

    it('should return the load to euro for Electricity', () => {
      const expectedConversion =
        20 * fluidConfig[FluidType.ELECTRICITY].coefficient
      const result = converterService.LoadToEuro(20, FluidType.ELECTRICITY)
      expect(result).toEqual(expectedConversion)
    })

    it('should return the load to euro for Gas', () => {
      const expectedConversion = 20 * fluidConfig[FluidType.GAS].coefficient
      const result = converterService.LoadToEuro(20, FluidType.GAS)
      expect(result).toEqual(expectedConversion)
    })

    it('should return the load to euro for Water', () => {
      const expectedConversion = 20 * fluidConfig[FluidType.WATER].coefficient
      const result = converterService.LoadToEuro(20, FluidType.WATER)
      expect(result).toEqual(expectedConversion)
    })

    it('should return the load to euro for Multifluid, no coeff apply', () => {
      const expectedConversion = 20
      const result = converterService.LoadToEuro(20, FluidType.MULTIFLUID)
      expect(result).toEqual(expectedConversion)
    })

    it('should return 0.01 if the load is below 0.01 euro', () => {
      const expectedConversion = 0.01
      const result = converterService.LoadToEuro(0.002, FluidType.WATER)
      expect(result).toEqual(expectedConversion)
    })

    it('should return 1.2 beacause there is a price of 1.2 set for doctype', () => {
      const expectedConversion = 1.2
      const result = converterService.LoadToEuro(0.002, FluidType.WATER, 1.2)
      expect(result).toEqual(expectedConversion)
    })
  })
})
