import {
  ConstructionYear,
  EquipmentType,
  Floor,
  FluidType,
  HotWaterEquipment,
  HotWaterFluid,
  HousingType,
  IndividualOrCollective,
  OutsideFacingWalls,
  ThreeChoicesAnswer,
  WarmingType,
} from 'enums'
import { DateTime } from 'luxon'
import { ProfileType } from 'models'
import { mockProfileTypeState } from 'tests/__mocks__/store'
import { profileTypeSlice, setProfileType } from './profileType.slice'

describe('profileType reducer', () => {
  it('should return the initial state', () => {
    const initialState = profileTypeSlice.reducer(undefined, {
      type: undefined,
    })
    expect(initialState).toEqual(mockProfileTypeState)
  })

  describe('setProfileType', () => {
    it('should handle update with partial payload', () => {
      const state = profileTypeSlice.reducer(
        mockProfileTypeState,
        setProfileType({ housingType: HousingType.APARTMENT })
      )
      expect(state).toEqual({
        ...mockProfileTypeState,
        housingType: HousingType.APARTMENT,
      })
    })

    it('should handle update with full payload', () => {
      const newProfileType: ProfileType = {
        housingType: HousingType.APARTMENT,
        constructionYear: ConstructionYear.AFTER_1998,
        area: '200',
        occupantsNumber: 8,
        outsideFacingWalls: OutsideFacingWalls.ONE,
        floor: Floor.INTERMEDIATE_FLOOR,
        heating: IndividualOrCollective.INDIVIDUAL,
        coldWater: IndividualOrCollective.INDIVIDUAL,
        hotWater: IndividualOrCollective.INDIVIDUAL,
        individualInsulationWork: [],
        hasInstalledVentilation: ThreeChoicesAnswer.YES,
        hasReplacedHeater: ThreeChoicesAnswer.YES,
        hotWaterEquipment: HotWaterEquipment.THERMODYNAMIC,
        warmingFluid: WarmingType.ELECTRICITY,
        hotWaterFluid: HotWaterFluid.ELECTRICITY,
        cookingFluid: FluidType.ELECTRICITY,
        updateDate: DateTime.fromISO('0000-01-01T00:00:00.000Z'),
        equipments: [EquipmentType.BOILER],
      }
      const state = profileTypeSlice.reducer(
        mockProfileTypeState,
        setProfileType(newProfileType)
      )
      expect(state).toEqual(newProfileType)
    })
  })
})
